@echo off
mkdir "00000000 - Inbox  收件箱（用于暂时存放待处理文件）"
mkdir "10000000 - Work  工作"
mkdir "10000000 - Work  工作\11000000 - Computer Science 计算机科学"
mkdir "10000000 - Work  工作\11000000 - Computer Science 计算机科学\11100000 - Software Development 软件开发"
mkdir "10000000 - Work  工作\11000000 - Computer Science 计算机科学\11100000 - Software Development 软件开发\11110000 - Projects 项目"
mkdir "10000000 - Work  工作\11000000 - Computer Science 计算机科学\11100000 - Software Development 软件开发\11120000 - Source Code 源代码"
mkdir "10000000 - Work  工作\11000000 - Computer Science 计算机科学\11100000 - Software Development 软件开发\11130000 - Documentation 文档"
mkdir "10000000 - Work  工作\11000000 - Computer Science 计算机科学\11200000 - Documentation 文档"
mkdir "10000000 - Work  工作\12000000 - Finance 金融"
mkdir "10000000 - Work  工作\12000000 - Finance 金融\12100000 - Investment 投资"
mkdir "10000000 - Work  工作\12000000 - Finance 金融\12100000 - Investment 投资\12110000 - Portfolio 组合"
mkdir "10000000 - Work  工作\12000000 - Finance 金融\12100000 - Investment 投资\12120000 - Transactions 交易记录"
mkdir "10000000 - Work  工作\12000000 - Finance 金融\12100000 - Investment 投资\12130000 - Reports 报告"
mkdir "10000000 - Work  工作\12000000 - Finance 金融\12200000 - Trading 交易"
mkdir "10000000 - Work  工作\12000000 - Finance 金融\12200000 - Trading 交易\12210000 - Strategies 策略"
mkdir "10000000 - Work  工作\12000000 - Finance 金融\12200000 - Trading 交易\12220000 - Orders 订单"
mkdir "10000000 - Work  工作\12000000 - Finance 金融\12200000 - Trading 交易\12230000 - Market Analysis 市场分析"
mkdir "10000000 - Work  工作\13000000 - Business 商业"
mkdir "10000000 - Work  工作\13000000 - Business 商业\13100000 - Management 管理"
mkdir "10000000 - Work  工作\13000000 - Business 商业\13100000 - Management 管理\13110000 - Plans 计划"
mkdir "10000000 - Work  工作\13000000 - Business 商业\13100000 - Management 管理\13120000 - Meetings 会议"
mkdir "10000000 - Work  工作\13000000 - Business 商业\13100000 - Management 管理\13130000 - Reports 报告"
mkdir "10000000 - Work  工作\13000000 - Business 商业\13200000 - Marketing 市场营销"
mkdir "10000000 - Work  工作\13000000 - Business 商业\13200000 - Marketing 市场营销\13210000 - Campaigns 活动"
mkdir "10000000 - Work  工作\13000000 - Business 商业\13200000 - Marketing 市场营销\13220000 - Analytics 数据分析"
mkdir "10000000 - Work  工作\13000000 - Business 商业\13200000 - Marketing 市场营销\13230000 - Content 内容"
mkdir "10000000 - Work  工作\14000000 - Literature 文学"
mkdir "10000000 - Work  工作\14000000 - Literature 文学\14100000 - Writing 写作"
mkdir "10000000 - Work  工作\14000000 - Literature 文学\14100000 - Writing 写作\14110000 - Drafts 草稿"
mkdir "10000000 - Work  工作\14000000 - Literature 文学\14100000 - Writing 写作\14120000 - Published 发表作品"
mkdir "10000000 - Work  工作\14000000 - Literature 文学\14100000 - Writing 写作\14130000 - Research 研究资料"
mkdir "10000000 - Work  工作\14000000 - Literature 文学\14200000 - Critique 评论"
mkdir "10000000 - Work  工作\14000000 - Literature 文学\14200000 - Critique 评论\14210000 - Reviews 评论"
mkdir "10000000 - Work  工作\14000000 - Literature 文学\14200000 - Critique 评论\14220000 - Analysis 分析"
mkdir "10000000 - Work  工作\14000000 - Literature 文学\14200000 - Critique 评论\14230000 - Essays 散文"
mkdir "10000000 - Work  工作\15000000 - Law 法律"
mkdir "10000000 - Work  工作\15000000 - Law 法律\15100000 - Legal Research 法律研究"
mkdir "10000000 - Work  工作\15000000 - Law 法律\15100000 - Legal Research 法律研究\15110000 - Case Law 判例法"
mkdir "10000000 - Work  工作\15000000 - Law 法律\15100000 - Legal Research 法律研究\15120000 - Statutory Law 法律条文"
mkdir "10000000 - Work  工作\15000000 - Law 法律\15100000 - Legal Research 法律研究\15130000 - Legal Commentary 法律评论"
mkdir "10000000 - Work  工作\15000000 - Law 法律\15200000 - Contracts 合同"
mkdir "10000000 - Work  工作\15000000 - Law 法律\15200000 - Contracts 合同\15210000 - Agreements 协议"
mkdir "10000000 - Work  工作\15000000 - Law 法律\15200000 - Contracts 合同\15220000 - Employment Contracts 雇佣合同"
mkdir "10000000 - Work  工作\15000000 - Law 法律\15200000 - Contracts 合同\15230000 - Lease Contracts 租赁合同"
mkdir "10000000 - Work  工作\16000000 - Interdisciplinary 跨学科"
mkdir "10000000 - Work  工作\16000000 - Interdisciplinary 跨学科\16100000 - Cross-disciplinary Research 跨学科研究"
mkdir "10000000 - Work  工作\16000000 - Interdisciplinary 跨学科\16200000 - Multidisciplinary Projects 多学科项目"
mkdir "10000000 - Work  工作\16000000 - Interdisciplinary 跨学科\16300000 - Integration Papers 整合论文"
mkdir "20000000 - Learning  学习"
mkdir "20000000 - Learning  学习\21000000 - ComputerScience 计算机科学"
mkdir "20000000 - Learning  学习\22000000 - Languages 语言学习"
mkdir "20000000 - Learning  学习\23000000 - Mathematics 数学"
mkdir "20000000 - Learning  学习\24000000 - Business 商业"
mkdir "20000000 - Learning  学习\25000000 - Economics  经济学"
mkdir "20000000 - Learning  学习\25000000 - Economics  经济学\25100000 - Finance 金融"
mkdir "20000000 - Learning  学习\26000000 - Psychology 心理学"
mkdir "20000000 - Learning  学习\27000000 - Miscellaneous 其他学科"
mkdir "20000000 - Learning  学习\27000000 - Miscellaneous 其他学科\27100000 - Sociology 社会学"
mkdir "20000000 - Learning  学习\27000000 - Miscellaneous 其他学科\27200000 - Literature 文学"
mkdir "20000000 - Learning  学习\27000000 - Miscellaneous 其他学科\27300000 - Philosophy 哲学"
mkdir "20000000 - Learning  学习\28000000 - Thesis 学术论文"
mkdir "20000000 - Learning  学习\29000000 - Exam Preparation 考试准备"
mkdir "30000000 - Interest  兴趣爱好"
mkdir "30000000 - Interest  兴趣爱好\31000000 - Photography 摄影"
mkdir "30000000 - Interest  兴趣爱好\32000000 - Video Editing 视频剪辑"
mkdir "30000000 - Interest  兴趣爱好\33000000 - Artificial Intelligence 人工智能"
mkdir "30000000 - Interest  兴趣爱好\34000000 - Technology 科技"
mkdir "30000000 - Interest  兴趣爱好\34000000 - Technology 科技\34100000 - Virtual Reality 虚拟现实"
mkdir "30000000 - Interest  兴趣爱好\34000000 - Technology 科技\34200000 - Robotics 机器人"
mkdir "30000000 - Interest  兴趣爱好\35000000 - PC Building 装机"
mkdir "30000000 - Interest  兴趣爱好\35000000 - PC Building 装机\35100000 - System Setup 系统安装"
mkdir "30000000 - Interest  兴趣爱好\35000000 - PC Building 装机\35200000 - 装机单"
mkdir "30000000 - Interest  兴趣爱好\36000000 - Geek 极客"
mkdir "30000000 - Interest  兴趣爱好\37000000 - Hacking 黑客技术"
mkdir "30000000 - Interest  兴趣爱好\38000000 - Miscellaneous 折腾"
mkdir "30000000 - Interest  兴趣爱好\39000000 - Miscellaneous 杂项文件"
mkdir "40000000 - Memories  回忆"
mkdir "40000000 - Memories  回忆\41000000 - Family 家庭"
mkdir "40000000 - Memories  回忆\42000000 - Friends 朋友"
mkdir "40000000 - Memories  回忆\43000000 - Travel 旅行"
mkdir "40000000 - Memories  回忆\44000000 - Special Occasions 特殊场合"
mkdir "40000000 - Memories  回忆\45000000 - School 学校"
mkdir "40000000 - Memories  回忆\46000000 - Diary 日记"
mkdir "40000000 - Memories  回忆\47000000 - Photo 照片"
mkdir "50000000 - Resource  资源"
mkdir "50000000 - Resource  资源\51000000 - Programs 程序"
mkdir "50000000 - Resource  资源\52000000 - Templates 模板"
mkdir "50000000 - Resource  资源\53000000 - E-books 电子书"
mkdir "50000000 - Resource  资源\54000000 - Magazines 杂志"
mkdir "50000000 - Resource  资源\55000000 - Images 图片"
mkdir "50000000 - Resource  资源\56000000 - Games"
mkdir "50000000 - Resource  资源\59000000 - Miscellaneous 其他文件"
mkdir "60000000 - ArtWork  艺术创作"
mkdir "60000000 - ArtWork  艺术创作\61000000 - Design 设计"
mkdir "60000000 - ArtWork  艺术创作\62000000 - Digital Art 数字艺术"
mkdir "60000000 - ArtWork  艺术创作\63000000 - Photography 摄影作品"
mkdir "60000000 - ArtWork  艺术创作\64000000 - Drawings 绘画作品"
mkdir "70000000 - MediaLibrary  媒体库"
mkdir "70000000 - MediaLibrary  媒体库\71000000 - Music 音乐"
mkdir "70000000 - MediaLibrary  媒体库\72000000 - Videos 视频"
mkdir "70000000 - MediaLibrary  媒体库\72100000 - Movies 电影"
mkdir "70000000 - MediaLibrary  媒体库\72200000 - Serials 电视剧"
mkdir "70000000 - MediaLibrary  媒体库\72300000 - Documentaries 纪录片"
mkdir "70000000 - MediaLibrary  媒体库\72400000 - Music Videos 音乐视频"
mkdir "70000000 - MediaLibrary  媒体库\73000000 - Podcasts 播客"
mkdir "70000000 - MediaLibrary  媒体库\74000000 - Audiobooks 音频书籍"
mkdir "80000000 - Archive  归档（用于存放历史文件和备份文件）"
mkdir "80000000 - Archive  归档（用于存放历史文件和备份文件）\81000000 - Old Files 旧文件"
mkdir "80000000 - Archive  归档（用于存放历史文件和备份文件）\82000000 - Backups 备份文件"
mkdir "80000000 - Archive  归档（用于存放历史文件和备份文件）\83000000 - Archived Projects 归档项目"
mkdir "90000000 - Miscellaneous  杂项文件（用于存放无法归类的文件）"
mkdir "90000000 - Miscellaneous  杂项文件（用于存放无法归类的文件）\91000000 - Downloads 下载文件"
mkdir "90000000 - Miscellaneous  杂项文件（用于存放无法归类的文件）\92000000 - Temp 临时文件"

echo 文件夹结构创建完毕。
pause
